@@ -16,21 +16,20 @@
  */
 package org.apache.camel.kamelets.catalog;
 
-import io.fabric8.camelk.v1alpha1.Kamelet;
-import io.fabric8.camelk.v1alpha1.JSONSchemaProps;
+import java.util.List;
+import java.util.Map;
+
+
 import io.github.classgraph.ClassGraph;
 import org.apache.camel.kamelets.catalog.model.KameletTypeEnum;
 import org.apache.camel.tooling.model.ComponentModel;
+import org.apache.camel.v1.Kamelet;
+import org.apache.camel.v1.kameletspec.Definition;
+import org.apache.camel.v1.kameletspec.Template;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-
-import java.util.List;
-import java.util.Map;
+import static org.junit.jupiter.api.Assertions.*;
 
 public class KameletsCatalogTest {
     static KameletsCatalog catalog;
@@ -43,20 +42,20 @@ public class KameletsCatalogTest {
     @Test
     void testGetKameletsName() throws Exception {
         List<String> names = catalog.getKameletsName();
-        assertTrue(!names.isEmpty());
+        assertFalse(names.isEmpty());
     }
 
     @Test
     void testGetKamelets() throws Exception {
         Map<String, Kamelet> kamelets = catalog.getKamelets();
-        assertTrue(!kamelets.isEmpty());
+        assertFalse(kamelets.isEmpty());
     }
-    
+
     @Test
     void testGetKameletsDefinition() throws Exception {
-        JSONSchemaProps props = catalog.getKameletDefinition("aws-sqs-source");
+        Definition props = catalog.getKameletDefinition("aws-sqs-source");
         assertEquals(14, props.getProperties().keySet().size());
-        assertTrue(props.getProperties().keySet().contains("queueNameOrArn"));
+        assertTrue(props.getProperties().containsKey("queueNameOrArn"));
     }
 
     @Test
@@ -68,14 +67,14 @@ public class KameletsCatalogTest {
 
     @Test
     void testGetKameletsDefinitionNotExists() throws Exception {
-        JSONSchemaProps props = catalog.getKameletDefinition("word");
+        Definition props = catalog.getKameletDefinition("word");
         assertNull(props);
     }
 
     @Test
     void testGetKameletsByProvider() throws Exception {
         List<Kamelet> c = catalog.getKameletByProvider("Apache Software Foundation");
-        assertTrue(!c.isEmpty());
+        assertFalse(c.isEmpty());
         c = catalog.getKameletByProvider("Eclipse");
         assertTrue(c.isEmpty());
     }
@@ -83,19 +82,19 @@ public class KameletsCatalogTest {
     @Test
     void testGetKameletsByType() throws Exception {
         List<Kamelet> c = catalog.getKameletsByType(KameletTypeEnum.SOURCE.type());
-        assertTrue(!c.isEmpty());
+        assertFalse(c.isEmpty());
         c = catalog.getKameletsByType(KameletTypeEnum.SINK.type());
-        assertTrue(!c.isEmpty());
+        assertFalse(c.isEmpty());
         c = catalog.getKameletsByType(KameletTypeEnum.ACTION.type());
-        assertTrue(!c.isEmpty());
+        assertFalse(c.isEmpty());
     }
 
     @Test
     void testGetKameletsByGroup() throws Exception {
         List<Kamelet> c = catalog.getKameletsByGroups("AWS S3");
-        assertTrue(!c.isEmpty());
+        assertFalse(c.isEmpty());
         c = catalog.getKameletsByGroups("AWS SQS");
-        assertTrue(!c.isEmpty());
+        assertFalse(c.isEmpty());
         c = catalog.getKameletsByGroups("Not-existing-group");
         assertTrue(c.isEmpty());
     }
@@ -103,8 +102,8 @@ public class KameletsCatalogTest {
     @Test
     void testGetKameletsByNamespace() throws Exception {
         List<Kamelet> c = catalog.getKameletsByNamespace("AWS");
-        assertTrue(!c.isEmpty());
-        assertTrue(c.size() == 27);
+        assertFalse(c.isEmpty());
+        assertEquals(25, c.size());
         c = catalog.getKameletsByGroups("Not-existing-group");
         assertTrue(c.isEmpty());
     }
@@ -120,10 +119,10 @@ public class KameletsCatalogTest {
 
     @Test
     void testGetKameletsTemplate() throws Exception {
-        Map<String, Object> template = catalog.getKameletTemplate("aws-sqs-source");
+        Template template = catalog.getKameletTemplate("aws-sqs-source");
         assertNotNull(template);
     }
-    
+
     @Test
     void testAllKameletFilesLoaded() throws Exception {
         int numberOfKameletFiles = new ClassGraph().acceptPaths("/" + KameletsCatalog.KAMELETS_DIR + "/").scan().getAllResources().size();
@@ -155,8 +154,8 @@ public class KameletsCatalogTest {
         verifyHeaders("couchbase-sink", 2);
         verifyHeaders("dropbox-source", 0);
         verifyHeaders("dropbox-source", 0);
-        verifyHeaders("elasticsearch-index-sink", 8);
-        verifyHeaders("elasticsearch-search-source", 8);
+        verifyHeaders("elasticsearch-index-sink", 9);
+        verifyHeaders("elasticsearch-search-source", 9);
         verifyHeaders("exec-sink", 0);
         verifyHeaders("fhir-source", 0);
         verifyHeaders("file-watch-source", 10);
@@ -184,14 +183,12 @@ public class KameletsCatalogTest {
         verifyHeaders("http-secured-sink", 14);
         verifyHeaders("infinispan-source", 6);
         verifyHeaders("infinispan-sink", 14);
-        verifyHeaders("jira-add-comment-sink", 16);
-        verifyHeaders("jira-add-issue-sink", 16);
+        verifyHeaders("jira-add-comment-sink", 17);
+        verifyHeaders("jira-add-issue-sink", 17);
         verifyHeaders("jira-source", 3);
         verifyHeaders("jira-oauth-source", 3);
         verifyHeaders("jms-amqp-10-source", 14);
         verifyHeaders("jms-amqp-10-sink", 17);
-        verifyHeaders("jms-apache-activemq-source", 14);
-        verifyHeaders("jms-apache-activemq-sink", 17);
         verifyHeaders("jms-apache-artemis-source", 14);
         verifyHeaders("jms-apache-artemis-sink", 17);
         verifyHeaders("jms-ibm-mq-source", 14);
@@ -229,21 +226,18 @@ public class KameletsCatalogTest {
         verifyHeaders("postgresql-source", 0);
         verifyHeaders("pulsar-sink", 4);
         verifyHeaders("pulsar-source", 11);
-        verifyHeaders("rabbitmq-source", 23);
         verifyHeaders("redis-sink", 29);
         verifyHeaders("redis-source", 28);
         verifyHeaders("rest-openapi-sink", 0);
         verifyHeaders("salesforce-create-sink", 1);
         verifyHeaders("salesforce-delete-sink", 1);
         verifyHeaders("salesforce-update-sink", 1);
-        verifyHeaders("salesforce-source", 18);
+        verifyHeaders("salesforce-source", 19);
         verifyHeaders("scp-sink", 0);
         verifyHeaders("sftp-sink", 8);
         verifyHeaders("sftp-source", 10);
         verifyHeaders("slack-sink", 0);
         verifyHeaders("slack-source", 0);
-        verifyHeaders("solr-sink", 5);
-        verifyHeaders("solr-source", 5);
         verifyHeaders("splunk-hec-sink", 1);
         verifyHeaders("splunk-sink", 0);
         verifyHeaders("splunk-source", 0);
@@ -258,7 +252,6 @@ public class KameletsCatalogTest {
         verifyHeaders("twitter-timeline-source", 1);
         verifyHeaders("twitter-search-source", 7);
         verifyHeaders("webhook-source", 0);
-        verifyHeaders("websocket-source", 4);
         verifyHeaders("wttrin-source", 5);
     }
 
@@ -267,7 +260,6 @@ public class KameletsCatalogTest {
         assertEquals(expected, headers.size());
     }
 
-
     @Test
     void testGetKameletScheme() throws Exception {
         assertEquals("aws2-s3", catalog.getKameletScheme("aws-s3"));
